@@ -12,23 +12,49 @@ use ordermap::OrderMap;
 use pixi_build_types::{self as pbt};
 
 use pixi_manifest::{PackageManifest, PackageTarget, TargetSelector, Targets};
-use pixi_spec::{GitReference, PixiSpec, SpecConversionError};
+use pixi_spec::{GitReference, PixiSpec, SourceSpec, SpecConversionError};
 use rattler_conda_types::{ChannelConfig, NamelessMatchSpec, PackageName};
 
 /// Conversion from a `PixiSpec` to a `pbt::PixiSpecV1`.
 fn to_pixi_spec_v1(
     spec: &PixiSpec,
     channel_config: &ChannelConfig,
-) -> Result<pbt::PackageSpecV1, SpecConversionError> {
+) -> Result<pbt::PackageSpec, SpecConversionError> {
     // Convert into source or binary
     let source_or_binary = spec.clone().into_source_or_binary();
     // Convert into correct type for pixi
     let pbt_spec = match source_or_binary {
         itertools::Either::Left(source) => {
-            let source = match source.location {
+            let SourceSpec {
+                location,
+                version,
+                build,
+                build_number,
+                extras: None,
+                subdir,
+                namespace: None,
+                license,
+                condition: None,
+            } = source
+            else {
+                unimplemented!(
+                    "a particular field is not implemented in the pixi to pbt conversion"
+                );
+            };
+            let location = match location {
                 pixi_spec::SourceLocationSpec::Url(url_source_spec) => {
-                    let pixi_spec::UrlSourceSpec { url, md5, sha256 } = url_source_spec;
-                    pbt::SourcePackageSpecV1::Url(pbt::UrlSpecV1 { url, md5, sha256 })
+                    let pixi_spec::UrlSourceSpec {
+                        url,
+                        md5,
+                        sha256,
+                        subdirectory,
+                    } = url_source_spec;
+                    pbt::SourcePackageLocationSpec::Url(pbt::UrlSpec {
+                        url,
+                        md5,
+                        sha256,
+                        subdirectory: subdirectory.to_option_string(),
+                    })
                 }
                 pixi_spec::SourceLocationSpec::Git(git_spec) => {
                     let pixi_spec::GitSpec {
@@ -36,24 +62,31 @@ fn to_pixi_spec_v1(
                         rev,
                         subdirectory,
                     } = git_spec;
-                    pbt::SourcePackageSpecV1::Git(pbt::GitSpecV1 {
+                    pbt::SourcePackageLocationSpec::Git(pbt::GitSpec {
                         git,
                         rev: rev.map(|r| match r {
-                            GitReference::Branch(b) => pbt::GitReferenceV1::Branch(b),
-                            GitReference::Tag(t) => pbt::GitReferenceV1::Tag(t),
-                            GitReference::Rev(rev) => pbt::GitReferenceV1::Rev(rev),
-                            GitReference::DefaultBranch => pbt::GitReferenceV1::DefaultBranch,
+                            GitReference::Branch(b) => pbt::GitReference::Branch(b),
+                            GitReference::Tag(t) => pbt::GitReference::Tag(t),
+                            GitReference::Rev(rev) => pbt::GitReference::Rev(rev),
+                            GitReference::DefaultBranch => pbt::GitReference::DefaultBranch,
                         }),
-                        subdirectory,
+                        subdirectory: subdirectory.to_option_string(),
                     })
                 }
                 pixi_spec::SourceLocationSpec::Path(path_source_spec) => {
-                    pbt::SourcePackageSpecV1::Path(pbt::PathSpecV1 {
+                    pbt::SourcePackageLocationSpec::Path(pbt::PathSpec {
                         path: path_source_spec.path.to_string(),
                     })
                 }
             };
-            pbt::PackageSpecV1::Source(source)
+            pbt::PackageSpec::Source(pbt::SourcePackageSpec {
+                location,
+                version,
+                build,
+                build_number,
+                subdir,
+                license,
+            })
         }
         itertools::Either::Right(binary) => {
             let NamelessMatchSpec {
@@ -72,7 +105,7 @@ fn to_pixi_spec_v1(
                 extras: _,
                 condition: _,
             } = binary.try_into_nameless_match_spec(channel_config)?;
-            pbt::PackageSpecV1::Binary(Box::new(pbt::BinaryPackageSpecV1 {
+            pbt::PackageSpec::Binary(pbt::BinaryPackageSpec {
                 version,
                 build,
                 build_number,
@@ -83,7 +116,7 @@ fn to_pixi_spec_v1(
                 sha256,
                 url,
                 license,
-            }))
+            })
         }
     };
     Ok(pbt_spec)
@@ -94,7 +127,7 @@ fn to_pixi_spec_v1(
 fn to_pbt_dependencies<'a>(
     iter: impl Iterator<Item = (&'a PackageName, &'a PixiSpec)>,
     channel_config: &ChannelConfig,
-) -> Result<OrderMap<pbt::SourcePackageName, pbt::PackageSpecV1>, SpecConversionError> {
+) -> Result<OrderMap<pbt::SourcePackageName, pbt::PackageSpec>, SpecConversionError> {
     iter.map(|(name, spec)| {
         let converted = to_pixi_spec_v1(spec, channel_config)?;
         Ok((name.as_normalized().to_string(), converted))
@@ -102,14 +135,14 @@ fn to_pbt_dependencies<'a>(
     .collect()
 }
 
-/// Converts a [`PackageTarget`] to a [`pbt::TargetV1`].
+/// Converts a [`PackageTarget`] to a [`pbt::Target`].
 fn to_target_v1(
     target: &PackageTarget,
     channel_config: &ChannelConfig,
-) -> Result<pbt::TargetV1, SpecConversionError> {
+) -> Result<pbt::Target, SpecConversionError> {
     // Difference for us is that [`pbt::TargetV1`] has split the host, run and build
     // dependencies into separate fields, so we need to split them up here
-    Ok(pbt::TargetV1 {
+    Ok(pbt::Target {
         host_dependencies: Some(
             target
                 .host_dependencies()
@@ -134,20 +167,20 @@ fn to_target_v1(
     })
 }
 
-pub fn to_target_selector_v1(selector: &TargetSelector) -> pbt::TargetSelectorV1 {
+pub fn to_target_selector_v1(selector: &TargetSelector) -> pbt::TargetSelector {
     match selector {
-        TargetSelector::Platform(platform) => pbt::TargetSelectorV1::Platform(platform.to_string()),
-        TargetSelector::Unix => pbt::TargetSelectorV1::Unix,
-        TargetSelector::Linux => pbt::TargetSelectorV1::Linux,
-        TargetSelector::Win => pbt::TargetSelectorV1::Win,
-        TargetSelector::MacOs => pbt::TargetSelectorV1::MacOs,
+        TargetSelector::Platform(platform) => pbt::TargetSelector::Platform(platform.to_string()),
+        TargetSelector::Unix => pbt::TargetSelector::Unix,
+        TargetSelector::Linux => pbt::TargetSelector::Linux,
+        TargetSelector::Win => pbt::TargetSelector::Win,
+        TargetSelector::MacOs => pbt::TargetSelector::MacOs,
     }
 }
 
 fn to_targets_v1(
     targets: &Targets<PackageTarget>,
     channel_config: &ChannelConfig,
-) -> Result<pbt::TargetsV1, SpecConversionError> {
+) -> Result<pbt::Targets, SpecConversionError> {
     let selected_targets = targets
         .iter()
         .filter_map(|(k, v)| {
@@ -156,21 +189,23 @@ fn to_targets_v1(
                     .map(|target| (to_target_selector_v1(selector), target))
             })
         })
-        .collect::<Result<OrderMap<pbt::TargetSelectorV1, pbt::TargetV1>, _>>()?;
+        .collect::<Result<OrderMap<pbt::TargetSelector, pbt::Target>, _>>()?;
 
-    Ok(pbt::TargetsV1 {
+    Ok(pbt::Targets {
         default_target: Some(to_target_v1(targets.default(), channel_config)?),
         targets: Some(selected_targets),
     })
 }
 
-/// Converts a [`PackageManifest`] to a [`pbt::ProjectModelV1`].
+/// Converts a [`PackageManifest`] to a [`pbt::ProjectModel`].
 pub fn to_project_model_v1(
     manifest: &PackageManifest,
     channel_config: &ChannelConfig,
-) -> Result<pbt::ProjectModelV1, SpecConversionError> {
-    let project = pbt::ProjectModelV1 {
+) -> Result<pbt::ProjectModel, SpecConversionError> {
+    let project = pbt::ProjectModel {
         name: manifest.package.name.clone(),
+        build_string: None,
+        build_number: None,
         version: manifest.package.version.clone(),
         description: manifest.package.description.clone(),
         authors: manifest.package.authors.clone(),
@@ -189,7 +224,6 @@ pub fn to_project_model_v1(
 mod tests {
     use std::path::PathBuf;
 
-    use pixi_build_types::VersionedProjectModel;
     use rattler_conda_types::ChannelConfig;
     use rstest::rstest;
 
@@ -222,10 +256,9 @@ mod tests {
                     .unwrap();
 
                 // Convert the manifest to the project model
-                let project_model: VersionedProjectModel =
+                let project_model =
                     super::to_project_model_v1(&package_manifest.value, &some_channel_config())
-                        .unwrap()
-                        .into();
+                        .unwrap();
                 let mut settings = insta::Settings::clone_current();
                 settings.set_snapshot_suffix(name);
                 settings.bind(|| {
