@@ -32,10 +32,15 @@ pub struct Args {
 }
 
 pub async fn execute(args: Args) -> miette::Result<()> {
-    let workspace = WorkspaceLocator::for_cli()
+    let mut workspace = WorkspaceLocator::for_cli()
         .with_search_start(args.workspace_config.workspace_locator_start())
         .locate()?;
 
+    // Apply backend override if provided (primarily for testing)
+    if let Some(backend_override) = args.workspace_config.backend_override.clone() {
+        workspace = workspace.with_backend_override(backend_override);
+    }
+
     // Update the lock-file, and extract it from the derived data to drop additional resources
     // created for the solve.
     // Use the silent version here since update_lock_file() will display the warning.
