@@ -11,7 +11,7 @@ use itertools::{Either, Itertools};
 use miette::Diagnostic;
 use pixi_build_types::procedures::conda_outputs::CondaOutput;
 use pixi_record::{PixiRecord, SourceRecord};
-use pixi_spec::{BinarySpec, PixiSpec, SourceAnchor, SourceSpec, SpecConversionError};
+use pixi_spec::{BinarySpec, PixiSpec, SourceAnchor, SourceLocationSpec, SpecConversionError};
 use pixi_spec_containers::DependencyMap;
 use rattler_conda_types::{
     ChannelConfig, InvalidPackageNameError, MatchSpec, PackageName, PackageRecord,
@@ -215,14 +215,15 @@ impl SourceMetadataSpec {
     ) -> Result<SourceRecord, CommandDispatcherError<SourceMetadataError>> {
         let manifest_source = source.manifest_source().clone();
         let build_source = source.build_source().cloned();
-        let source_anchor = SourceAnchor::from(SourceSpec::from(manifest_source.clone()));
+        let source_anchor = SourceAnchor::from(SourceLocationSpec::from(manifest_source.clone()));
 
         // Solve the build environment for the output.
+        let mut compatibility_map = HashMap::new();
         let build_dependencies = output
             .build_dependencies
             .as_ref()
             // TODO(tim): we need to check if this works for out-of-tree builds with source dependencies in the out-of-tree, this might be incorrectly anchored
-            .map(|deps| Dependencies::new(deps, Some(source_anchor.clone())))
+            .map(|deps| Dependencies::new(deps, Some(source_anchor.clone()), &compatibility_map))
             .transpose()
             .map_err(SourceMetadataError::from)
             .map_err(CommandDispatcherError::Failed)?
@@ -248,14 +249,22 @@ impl SourceMetadataSpec {
                 reporter.clone(),
             )
             .await
-            .map_err(|err| SourceMetadataError::RunExportsExtraction(String::from("build"), err))
+            .map_err(|err| {
+                SourceMetadataError::RunExportsExtraction(String::from("build"), Arc::new(err))
+            })
             .map_err(CommandDispatcherError::Failed)?;
 
+        compatibility_map.extend(
+            build_records
+                .iter()
+                .map(|record| (record.package_record().name.clone(), record)),
+        );
+
         // Solve the host environment for the output.
         let host_dependencies = output
             .host_dependencies
             .as_ref()
-            .map(|deps| Dependencies::new(deps, Some(source_anchor.clone())))
+            .map(|deps| Dependencies::new(deps, Some(source_anchor.clone()), &compatibility_map))
             .transpose()
             .map_err(SourceMetadataError::from)
             .map_err(CommandDispatcherError::Failed)?
@@ -279,51 +288,63 @@ impl SourceMetadataSpec {
                 reporter,
             )
             .await
-            .map_err(|err| SourceMetadataError::RunExportsExtraction(String::from("host"), err))
+            .map_err(|err| {
+                SourceMetadataError::RunExportsExtraction(String::from("host"), Arc::new(err))
+            })
             .map_err(CommandDispatcherError::Failed)?;
 
+        compatibility_map.extend(
+            host_records
+                .iter()
+                .map(|record| (record.package_record().name.clone(), record)),
+        );
+
         // Gather the dependencies for the output.
-        let run_dependencies = Dependencies::new(&output.run_dependencies, None)
-            .map_err(SourceMetadataError::from)
-            .map_err(CommandDispatcherError::Failed)?
-            .extend_with_run_exports_from_build_and_host(
-                host_run_exports,
-                build_run_exports,
-                output.metadata.subdir,
-            );
+        let run_dependencies =
+            Dependencies::new(&output.run_dependencies, None, &compatibility_map)
+                .map_err(SourceMetadataError::from)
+                .map_err(CommandDispatcherError::Failed)?
+                .extend_with_run_exports_from_build_and_host(
+                    host_run_exports,
+                    build_run_exports,
+                    output.metadata.subdir,
+                );
 
         let PackageRecordDependencies {
             depends,
             constrains,
             mut sources,
         } = PackageRecordDependencies::new(run_dependencies, &self.backend_metadata.channel_config)
-            .map_err(SourceMetadataError::SpecConversionError)
-            .map_err(CommandDispatcherError::Failed)?;
-
-        // Convert the run exports
-        let run_exports = PixiRunExports::try_from_protocol(&output.run_exports)
             .map_err(SourceMetadataError::from)
             .map_err(CommandDispatcherError::Failed)?;
 
+        // Convert the run exports
+        let run_exports =
+            PixiRunExports::try_from_protocol(&output.run_exports, &compatibility_map)
+                .map_err(SourceMetadataError::from)
+                .map_err(CommandDispatcherError::Failed)?;
+
         let pixi_spec_to_match_spec = |name: &PackageName,
                                        spec: &PixiSpec,
-                                       sources: &mut HashMap<PackageName, SourceSpec>|
+                                       sources: &mut HashMap<PackageName, SourceLocationSpec>|
          -> Result<MatchSpec, SourceMetadataError> {
             match spec.clone().into_source_or_binary() {
                 Either::Left(source) => {
-                    let source = match sources.entry(name.clone()) {
+                    match sources.entry(name.clone()) {
                         std::collections::hash_map::Entry::Occupied(entry) => {
                             // If the entry already exists, check if it points to the same source.
-                            if entry.get() == &source {
+                            if entry.get() == &source.location {
                                 return Err(SourceMetadataError::DuplicateSourceDependency {
                                     package: name.clone(),
                                     source1: Box::new(entry.get().clone()),
-                                    source2: Box::new(source.clone()),
+                                    source2: Box::new(source.location.clone()),
                                 });
                             }
                             entry.into_mut()
                         }
-                        std::collections::hash_map::Entry::Vacant(entry) => entry.insert(source),
+                        std::collections::hash_map::Entry::Vacant(entry) => {
+                            entry.insert(source.location.clone())
+                        }
                     };
                     Ok(MatchSpec::from_nameless(
                         source.to_nameless_match_spec(),
@@ -333,14 +354,14 @@ impl SourceMetadataSpec {
                 Either::Right(binary) => {
                     let spec = binary
                         .try_into_nameless_match_spec(&self.backend_metadata.channel_config)
-                        .map_err(SourceMetadataError::SpecConversionError)?;
+                        .map_err(SourceMetadataError::from)?;
                     Ok(MatchSpec::from_nameless(spec, Some(name.clone().into())))
                 }
             }
         };
 
         let pixi_specs_to_match_spec = |specs: DependencyMap<PackageName, PixiSpec>,
-                                        sources: &mut HashMap<PackageName, SourceSpec>|
+                                        sources: &mut HashMap<PackageName, SourceLocationSpec>|
          -> Result<
             Vec<String>,
             CommandDispatcherError<SourceMetadataError>,
@@ -361,7 +382,7 @@ impl SourceMetadataSpec {
                 .map(|(name, spec)| {
                     let nameless_spec = spec
                         .try_into_nameless_match_spec(&self.backend_metadata.channel_config)
-                        .map_err(SourceMetadataError::SpecConversionError)?;
+                        .map_err(SourceMetadataError::from)?;
                     Ok(MatchSpec::from_nameless(nameless_spec, Some(name.into())).to_string())
                 })
                 .collect::<Result<Vec<_>, SourceMetadataError>>()
@@ -520,7 +541,7 @@ impl SourceMetadataSpec {
 struct PackageRecordDependencies {
     pub depends: Vec<String>,
     pub constrains: Vec<String>,
-    pub sources: HashMap<rattler_conda_types::PackageName, SourceSpec>,
+    pub sources: HashMap<rattler_conda_types::PackageName, SourceLocationSpec>,
 }
 
 impl PackageRecordDependencies {
@@ -544,14 +565,12 @@ impl PackageRecordDependencies {
         for (name, spec) in dependencies.dependencies.into_specs() {
             match spec.value.into_source_or_binary() {
                 Either::Left(source) => {
-                    depends.push(
-                        MatchSpec {
-                            name: Some(name.clone().into()),
-                            ..MatchSpec::default()
-                        }
-                        .to_string(),
+                    let spec = MatchSpec::from_nameless(
+                        source.to_nameless_match_spec(),
+                        Some(name.clone().into()),
                     );
-                    sources.insert(name, source);
+                    depends.push(spec.to_string());
+                    sources.insert(name, source.location);
                 }
                 Either::Right(binary) => {
                     if let Ok(spec) = binary.try_into_nameless_match_spec(channel_config) {
@@ -568,14 +587,14 @@ impl PackageRecordDependencies {
     }
 }
 
-#[derive(Debug, Error, Diagnostic)]
+#[derive(Debug, Clone, Error, Diagnostic)]
 pub enum SourceMetadataError {
     #[error(transparent)]
     #[diagnostic(transparent)]
     BuildBackendMetadata(#[from] BuildBackendMetadataError),
 
     #[error("failed to amend run exports for {0} environment")]
-    RunExportsExtraction(String, #[source] RunExportExtractorError),
+    RunExportsExtraction(String, #[source] Arc<RunExportExtractorError>),
 
     #[error("while trying to solve the build environment for the package")]
     SolveBuildEnvironment(
@@ -592,17 +611,20 @@ pub enum SourceMetadataError {
     ),
 
     #[error(transparent)]
-    SpecConversionError(#[from] SpecConversionError),
+    SpecConversionError(Arc<SpecConversionError>),
 
-    #[error("backend returned a dependency on an invalid package name: {0}")]
-    InvalidPackageName(String, #[source] InvalidPackageNameError),
+    #[error(transparent)]
+    InvalidPackageName(Arc<InvalidPackageNameError>),
+
+    #[error(transparent)]
+    PinCompatibleError(#[from] crate::build::pin_compatible::PinCompatibleError),
 
     #[error("found two source dependencies for {} but for different sources ({source1} and {source2})", package.as_source()
     )]
     DuplicateSourceDependency {
         package: PackageName,
-        source1: Box<SourceSpec>,
-        source2: Box<SourceSpec>,
+        source1: Box<SourceLocationSpec>,
+        source2: Box<SourceLocationSpec>,
     },
 
     #[error("the dependencies of some packages in the environment form a cycle")]
@@ -616,11 +638,26 @@ pub enum SourceMetadataError {
     PackageNotProvided(#[from] PackageNotProvidedError),
 }
 
+impl From<SpecConversionError> for SourceMetadataError {
+    fn from(err: SpecConversionError) -> Self {
+        Self::SpecConversionError(Arc::new(err))
+    }
+}
+
+impl From<InvalidPackageNameError> for SourceMetadataError {
+    fn from(err: InvalidPackageNameError) -> Self {
+        Self::InvalidPackageName(Arc::new(err))
+    }
+}
+
 impl From<DependenciesError> for SourceMetadataError {
     fn from(value: DependenciesError) -> Self {
         match value {
-            DependenciesError::InvalidPackageName(name, error) => {
-                SourceMetadataError::InvalidPackageName(name, error)
+            DependenciesError::InvalidPackageName(error) => {
+                SourceMetadataError::InvalidPackageName(error)
+            }
+            DependenciesError::PinCompatibleError(error) => {
+                SourceMetadataError::PinCompatibleError(error)
             }
         }
     }
