@@ -77,6 +77,22 @@ fn workspaces_dir() -> PathBuf {
     cargo_workspace_dir().join("tests/data/workspaces")
 }
 
+/// Recursively copies a directory from `src` to `dst`.
+fn copy_dir_recursive(src: &Path, dst: &Path) -> std::io::Result<()> {
+    fs::create_dir_all(dst)?;
+    for entry in fs::read_dir(src)? {
+        let entry = entry?;
+        let src_path = entry.path();
+        let dst_path = dst.join(entry.file_name());
+        if src_path.is_dir() {
+            copy_dir_recursive(&src_path, &dst_path)?;
+        } else {
+            fs::copy(&src_path, &dst_path)?;
+        }
+    }
+    Ok(())
+}
+
 /// Returns the default build environment to use for tests.
 fn default_build_environment() -> BuildEnvironment {
     let (tool_platform, tool_virtual_packages) = tool_platform();
@@ -432,15 +448,11 @@ pub async fn test_cycle() {
 /// package and any package that specifies it as a host dependency.
 #[tokio::test]
 pub async fn test_stale_host_dependency_triggers_rebuild() {
-    // Construct a command dispatcher with:
-    // - a root directory located in the `cycle` workspace
-    // - the default cache directories but with a temporary workspace cache
-    //   directory
-    // - the default tool platform and virtual packages
-    // - a backend override that uses a passthrough backend to avoid any actual
-    //   backend calls
-    let root_dir = workspaces_dir().join("host-dependency");
+    // Copy workspace to temp directory so we can modify files without affecting other tests
+    let source_dir = workspaces_dir().join("host-dependency");
     let tempdir = tempfile::tempdir().unwrap();
+    let root_dir = tempdir.path().join("workspace");
+    copy_dir_recursive(&source_dir, &root_dir).unwrap();
     let (tool_platform, tool_virtual_packages) = tool_platform();
     let build_env = BuildEnvironment::simple(tool_platform, tool_virtual_packages.clone());
     let build_command_dispatcher = || {
@@ -562,22 +574,6 @@ pub async fn instantiate_backend_with_from_source() {
     let source_dir = workspaces_dir().join("source-backends");
     let tmp_dir = tempfile::tempdir().unwrap();
     let root_dir = tmp_dir.path().to_path_buf();
-
-    // Copy all files from source to temp
-    fn copy_dir_recursive(src: &Path, dst: &Path) -> std::io::Result<()> {
-        fs_err::create_dir_all(dst)?;
-        for entry in fs_err::read_dir(src)? {
-            let entry = entry?;
-            let src_path = entry.path();
-            let dst_path = dst.join(entry.file_name());
-            if src_path.is_dir() {
-                copy_dir_recursive(&src_path, &dst_path)?;
-            } else {
-                fs_err::copy(&src_path, &dst_path)?;
-            }
-        }
-        Ok(())
-    }
     copy_dir_recursive(&source_dir, &root_dir).unwrap();
 
     // Update workspace pixi.toml to use local channel instead of conda-forge
@@ -1341,8 +1337,12 @@ pub async fn test_package_not_rebuilt_across_sessions_when_no_files_changed() {
 /// and verifies that file changes are detected and trigger a rebuild.
 #[tokio::test]
 pub async fn test_package_rebuilt_across_sessions_when_source_file_modified() {
-    let root_dir = workspaces_dir().join("host-dependency");
+    // Copy workspace to temp directory so we can modify files without affecting other tests
+    let source_dir = workspaces_dir().join("host-dependency");
     let tempdir = tempfile::tempdir().unwrap();
+    let root_dir = tempdir.path().join("workspace");
+    copy_dir_recursive(&source_dir, &root_dir).unwrap();
+
     let (tool_platform, tool_virtual_packages) = tool_platform();
     let build_env = BuildEnvironment::simple(tool_platform, tool_virtual_packages.clone());
 
@@ -1393,10 +1393,7 @@ pub async fn test_package_rebuilt_across_sessions_when_source_file_modified() {
     drop(dispatcher);
 
     // Create a file that matches package-b's build glob pattern ("TOUCH*")
-    let _touch_file = tempfile::Builder::new()
-        .prefix("TOUCH")
-        .tempfile_in(root_dir.join("package-b"))
-        .unwrap();
+    fs_err::write(root_dir.join("package-b/TOUCH_FILE"), "trigger rebuild").unwrap();
 
     // Second session: reinstall after file modification
     let (reporter, events) = EventReporter::new();
@@ -1435,8 +1432,11 @@ pub async fn test_package_rebuilt_across_sessions_when_source_file_modified() {
 /// without testing dependency chains or force rebuild flags.
 #[tokio::test]
 pub async fn test_package_rebuilt_when_source_file_modified() {
-    let root_dir = workspaces_dir().join("host-dependency");
+    // Copy workspace to temp directory so we can modify files without affecting other tests
+    let source_dir = workspaces_dir().join("host-dependency");
     let tempdir = tempfile::tempdir().unwrap();
+    let root_dir = tempdir.path().join("workspace");
+    copy_dir_recursive(&source_dir, &root_dir).unwrap();
     let (tool_platform, tool_virtual_packages) = tool_platform();
     let build_env = BuildEnvironment::simple(tool_platform, tool_virtual_packages.clone());
 
@@ -1713,8 +1713,11 @@ pub async fn test_metadata_refetched_when_source_file_modified() {
     use pixi_command_dispatcher::{BuildBackendMetadataSpec, DevSourceMetadataSpec};
     use pixi_record::PinnedPathSpec;
 
-    let root_dir = workspaces_dir().join("host-dependency");
+    // Copy workspace to temp directory so we can modify files without affecting other tests
+    let source_dir = workspaces_dir().join("host-dependency");
     let tempdir = tempfile::tempdir().unwrap();
+    let root_dir = tempdir.path().join("workspace");
+    copy_dir_recursive(&source_dir, &root_dir).unwrap();
     let (tool_platform, tool_virtual_packages) = tool_platform();
 
     let build_command_dispatcher = || {
