@@ -6,7 +6,7 @@ use pypi_modifiers::pypi_tags::{PyPITagError, get_tags_from_machine, is_python_r
 use rattler_conda_types::ParseStrictness::Lenient;
 use rattler_conda_types::{GenericVirtualPackage, MatchSpec, Matches, PackageName, PackageRecord};
 use rattler_conda_types::{ParseMatchSpecError, Platform};
-use rattler_lock::{ConversionError, LockFile, PypiPackageData};
+use rattler_lock::{CondaPackageData, ConversionError, LockFile, PypiPackageData};
 use rattler_virtual_packages::{
     DetectVirtualPackageError, VirtualPackage, VirtualPackageOverrides,
 };
@@ -166,19 +166,28 @@ pub(crate) fn validate_system_meets_environment_requirements(
         MachineValidationError::EnvironmentNotFound(environment_name.as_str().to_string()),
     )?;
 
-    // Retrieve the conda package records for the specified platform.
-    let Some(conda_data) = environment
-        .conda_repodata_records(platform)
-        .map_err(MachineValidationError::RepodataConversionError)?
-    else {
-        // Early out if there are no conda records, as we don't need to check for virtual packages
+    // Retrieve all conda packages for the specified platform (both binary and source).
+    let Some(conda_packages) = environment.conda_packages(platform) else {
+        // Early out if there are no packages, as we don't need to check for virtual packages
         return Ok(true);
     };
 
-    let conda_records: Vec<&PackageRecord> = conda_data
+    // Collect conda packages (both binary and source) into a vector of CondaPackageData
+    let conda_packages: Vec<&CondaPackageData> = conda_packages.collect_vec();
+
+    if conda_packages.is_empty() {
+        // Early out if there are no conda records, as we don't need to check for virtual packages
+        return Ok(true);
+    }
+
+    // Get package records from both binary and source packages
+    let conda_records = conda_packages
         .iter()
-        .map(|record| &record.package_record)
-        .collect();
+        .map(|data| match data {
+            CondaPackageData::Binary(binary) => &binary.package_record,
+            CondaPackageData::Source(source) => &source.package_record,
+        })
+        .collect_vec();
 
     // Get the virtual packages required by the conda records
     let required_virtual_packages =
