@@ -1,7 +1,7 @@
 use crate::{PixiPypiSource, PixiPypiSpec, VersionOrStar};
 use itertools::Itertools;
-use pep508_rs::ExtraName;
-use pixi_spec::{GitReference, GitSpec};
+use pep508_rs::{ExtraName, MarkerTree};
+use pixi_spec::{GitReference, GitSpec, SubdirectoryError};
 use pixi_toml::{TomlFromStr, TomlWith};
 use std::fmt::Display;
 use std::path::PathBuf;
@@ -21,6 +21,8 @@ pub enum SpecConversion {
     VersionWithNonDetailedKeys { non_detailed_keys: String },
     #[error("Exactly one of `url`, `path`, `git`, or `version` must be specified")]
     MultipleVersionSpecifiers,
+    #[error(transparent)]
+    InvalidSubdirectory(#[from] SubdirectoryError),
 }
 
 /// Returns a more helpful message when a version requirement is used
@@ -58,6 +60,8 @@ struct RawPyPiRequirement {
 
     extras: Vec<ExtraName>,
 
+    marker: MarkerTree,
+
     // Path Only
     pub path: Option<PathBuf>,
     pub editable: Option<bool>,
@@ -111,19 +115,25 @@ impl RawPyPiRequirement {
         }
 
         let req = match (self.url, self.path, self.git, self.index) {
-            (Some(url), None, None, None) => PixiPypiSpec::with_extras(
+            (Some(url), None, None, None) => PixiPypiSpec::with_extras_and_markers(
                 PixiPypiSource::Url {
                     url,
-                    subdirectory: self.subdirectory,
+                    subdirectory: self
+                        .subdirectory
+                        .map(pixi_spec::Subdirectory::try_from)
+                        .transpose()?
+                        .unwrap_or_default(),
                 },
                 self.extras,
+                self.marker,
             ),
-            (None, Some(path), None, None) => PixiPypiSpec::with_extras(
+            (None, Some(path), None, None) => PixiPypiSpec::with_extras_and_markers(
                 PixiPypiSource::Path {
                     path,
                     editable: self.editable,
                 },
                 self.extras,
+                self.marker,
             ),
             (None, None, Some(git), None) => {
                 let rev = match (self.branch, self.rev, self.tag) {
@@ -135,23 +145,29 @@ impl RawPyPiRequirement {
                         return Err(SpecConversion::MultipleGitSpecifiers);
                     }
                 };
-                PixiPypiSpec::with_extras(
+                PixiPypiSpec::with_extras_and_markers(
                     PixiPypiSource::Git {
                         git: GitSpec {
                             git,
                             rev,
-                            subdirectory: self.subdirectory,
+                            subdirectory: self
+                                .subdirectory
+                                .map(pixi_spec::Subdirectory::try_from)
+                                .transpose()?
+                                .unwrap_or_default(),
                         },
                     },
                     self.extras,
+                    self.marker,
                 )
             }
-            (None, None, None, index) => PixiPypiSpec::with_extras(
+            (None, None, None, index) => PixiPypiSpec::with_extras_and_markers(
                 PixiPypiSource::Registry {
                     version: self.version.unwrap_or(VersionOrStar::Star),
                     index,
                 },
                 self.extras,
+                self.marker,
             ),
             _ => {
                 return Err(SpecConversion::MultipleVersionSpecifiers);
@@ -196,6 +212,11 @@ impl<'de> toml_span::Deserialize<'de> for RawPyPiRequirement {
             .optional::<TomlFromStr<_>>("index")
             .map(TomlFromStr::into_inner);
 
+        let marker = th
+            .optional::<TomlFromStr<_>>("env-markers")
+            .map(TomlFromStr::into_inner)
+            .unwrap_or_default();
+
         th.finalize(None)?;
 
         Ok(RawPyPiRequirement {
@@ -210,6 +231,7 @@ impl<'de> toml_span::Deserialize<'de> for RawPyPiRequirement {
             url,
             subdirectory,
             index,
+            marker,
         })
     }
 }
@@ -264,6 +286,16 @@ impl From<PixiPypiSpec> for toml_edit::Value {
             }
         }
 
+        fn insert_markers(table: &mut toml_edit::InlineTable, markers: &MarkerTree) {
+            let markers_str = markers.try_to_string();
+            if let Some(markers_str) = markers_str {
+                table.insert(
+                    "env-markers",
+                    toml_edit::Value::String(toml_edit::Formatted::new(markers_str)),
+                );
+            }
+        }
+
         fn insert_index(table: &mut toml_edit::InlineTable, index: &Option<Url>) {
             if let Some(index) = index {
                 table.insert(
@@ -274,10 +306,13 @@ impl From<PixiPypiSpec> for toml_edit::Value {
         }
 
         let extras = &val.extras;
+        let markers = &val.env_markers;
 
         match &val.source {
             // Simple version string (no extras, no index)
-            PixiPypiSource::Registry { version, index } if extras.is_empty() && index.is_none() => {
+            PixiPypiSource::Registry { version, index }
+                if extras.is_empty() && index.is_none() && markers.is_true() =>
+            {
                 toml_edit::Value::from(version.to_string())
             }
             // Registry with extras or index
@@ -289,6 +324,7 @@ impl From<PixiPypiSpec> for toml_edit::Value {
                 );
                 insert_extras(&mut table, extras);
                 insert_index(&mut table, index);
+                insert_markers(&mut table, markers);
                 toml_edit::Value::InlineTable(table.to_owned())
             }
             PixiPypiSource::Git {
@@ -329,7 +365,7 @@ impl From<PixiPypiSpec> for toml_edit::Value {
                     }
                 };
 
-                if let Some(subdirectory) = subdirectory {
+                if !subdirectory.is_empty() {
                     table.insert(
                         "subdirectory",
                         toml_edit::Value::String(toml_edit::Formatted::new(
@@ -338,6 +374,7 @@ impl From<PixiPypiSpec> for toml_edit::Value {
                     );
                 }
                 insert_extras(&mut table, extras);
+                insert_markers(&mut table, markers);
                 toml_edit::Value::InlineTable(table.to_owned())
             }
             PixiPypiSource::Path { path, editable } => {
@@ -355,6 +392,7 @@ impl From<PixiPypiSpec> for toml_edit::Value {
                     );
                 }
                 insert_extras(&mut table, extras);
+                insert_markers(&mut table, markers);
                 toml_edit::Value::InlineTable(table.to_owned())
             }
             PixiPypiSource::Url { url, subdirectory } => {
@@ -363,7 +401,7 @@ impl From<PixiPypiSpec> for toml_edit::Value {
                     "url",
                     toml_edit::Value::String(toml_edit::Formatted::new(url.to_string())),
                 );
-                if let Some(subdirectory) = subdirectory {
+                if !subdirectory.is_empty() {
                     table.insert(
                         "subdirectory",
                         toml_edit::Value::String(toml_edit::Formatted::new(
@@ -372,6 +410,7 @@ impl From<PixiPypiSpec> for toml_edit::Value {
                     );
                 }
                 insert_extras(&mut table, extras);
+                insert_markers(&mut table, markers);
                 toml_edit::Value::InlineTable(table.to_owned())
             }
         }
@@ -472,12 +511,13 @@ mod test {
         );
         assert_eq!(
             requirement.first().unwrap().1,
-            &PixiPypiSpec::with_extras(
+            &PixiPypiSpec::with_extras_and_markers(
                 PixiPypiSource::Registry {
                     version: ">=3.12".parse().unwrap(),
                     index: None,
                 },
                 vec![ExtraName::from_str("bar").unwrap()],
+                pep508_rs::MarkerTree::default(),
             )
         );
 
@@ -492,7 +532,7 @@ mod test {
         );
         assert_eq!(
             requirement.first().unwrap().1,
-            &PixiPypiSpec::with_extras(
+            &PixiPypiSpec::with_extras_and_markers(
                 PixiPypiSource::Registry {
                     version: ">=3.12,<3.13.0".parse().unwrap(),
                     index: None,
@@ -501,6 +541,7 @@ mod test {
                     ExtraName::from_str("bar").unwrap(),
                     ExtraName::from_str("foo").unwrap(),
                 ],
+                pep508_rs::MarkerTree::default(),
             )
         );
     }
@@ -511,13 +552,14 @@ mod test {
             r#"
         version = "==1.2.3"
         extras = ["feature1", "feature2"]
+        env-markers = "python_version >= '3.11'"
         "#,
         )
         .unwrap();
 
         assert_eq!(
             pypi_requirement,
-            PixiPypiSpec::with_extras(
+            PixiPypiSpec::with_extras_and_markers(
                 PixiPypiSource::Registry {
                     version: "==1.2.3".parse().unwrap(),
                     index: None,
@@ -526,6 +568,7 @@ mod test {
                     ExtraName::from_str("feature1").unwrap(),
                     ExtraName::from_str("feature2").unwrap()
                 ],
+                pep508_rs::MarkerTree::from_str("python_version >= '3.11'").unwrap(),
             )
         );
     }
@@ -587,14 +630,14 @@ mod test {
     #[test]
     fn test_deserialize_fail_on_unknown() {
         let input = r#"foo = { borked = "bork"}"#;
-        assert_snapshot!(format_parse_error(input, from_toml_str::<TomlIndexMap::<pep508_rs::PackageName, PixiPypiSpec>>(input).unwrap_err()), @r###"
-         × Unexpected keys, expected only 'version', 'extras', 'path', 'editable', 'git', 'branch', 'tag', 'rev', 'url', 'subdirectory', 'index'
+        assert_snapshot!(format_parse_error(input, from_toml_str::<TomlIndexMap::<pep508_rs::PackageName, PixiPypiSpec>>(input).unwrap_err()), @r#"
+         × Unexpected keys, expected only 'version', 'extras', 'path', 'editable', 'git', 'branch', 'tag', 'rev', 'url', 'subdirectory', 'index', 'env-markers'
           ╭─[pixi.toml:1:9]
         1 │ foo = { borked = "bork"}
           ·         ───┬──
           ·            ╰── 'borked' was not expected here
           ╰────
-        "###);
+        "#);
     }
 
     #[test]
@@ -609,7 +652,7 @@ mod test {
             requirement.first().unwrap().1,
             &PixiPypiSpec::new(PixiPypiSource::Url {
                 url: Url::parse("https://test.url.com").unwrap(),
-                subdirectory: None,
+                subdirectory: Default::default(),
             })
         );
     }
@@ -627,7 +670,7 @@ mod test {
                 git: GitSpec {
                     git: Url::parse("https://test.url.git").unwrap(),
                     rev: None,
-                    subdirectory: None,
+                    subdirectory: Default::default(),
                 },
             })
         );
@@ -646,7 +689,7 @@ mod test {
                 git: GitSpec {
                     git: Url::parse("https://test.url.git").unwrap(),
                     rev: Some(GitReference::Branch("main".to_string())),
-                    subdirectory: None,
+                    subdirectory: Default::default(),
                 },
             })
         );
@@ -665,7 +708,7 @@ mod test {
                 git: GitSpec {
                     git: Url::parse("https://test.url.git").unwrap(),
                     rev: Some(GitReference::Tag("v.1.2.3".to_string())),
-                    subdirectory: None,
+                    subdirectory: Default::default(),
                 },
             })
         );
@@ -684,7 +727,7 @@ mod test {
                 git: GitSpec {
                     git: Url::parse("https://github.com/pallets/flask.git").unwrap(),
                     rev: Some(GitReference::Tag("3.0.0".to_string())),
-                    subdirectory: None,
+                    subdirectory: Default::default(),
                 },
             }),
         );
@@ -703,7 +746,7 @@ mod test {
                 git: GitSpec {
                     git: Url::parse("https://test.url.git").unwrap(),
                     rev: Some(GitReference::Rev("123456".to_string())),
-                    subdirectory: None,
+                    subdirectory: Default::default(),
                 },
             })
         );
