@@ -133,9 +133,11 @@ pub fn as_uv_req(
                         .transpose()
                         .expect("could not parse sha"),
                 )?,
-                subdirectory: subdirectory
-                    .as_ref()
-                    .map(|s| PathBuf::from(s).into_boxed_path()),
+                subdirectory: if subdirectory.is_empty() {
+                    None
+                } else {
+                    Some(subdirectory.as_path().to_path_buf().into_boxed_path())
+                },
                 // The full url used to clone, comparable to the git+ url in pip. e.g:
                 // - 'git+SCHEMA://HOST/PATH@REF#subdirectory=SUBDIRECTORY'
                 // - 'git+ssh://github.com/user/repo@d099af3b1028b00c232d8eda28a997984ae5848b'
@@ -143,7 +145,7 @@ pub fn as_uv_req(
                     let created_url = create_uv_url(
                         git_url.without_git_prefix(),
                         rev.as_ref(),
-                        subdirectory.as_deref(),
+                        subdirectory.to_option_string().as_deref(),
                     )
                     .map_err(|e| AsPep508Error::UrlParseError {
                         source: e,
@@ -203,9 +205,11 @@ pub fn as_uv_req(
             let verbatim_url = VerbatimUrl::from_url(url.clone().into());
 
             RequirementSource::Url {
-                subdirectory: subdirectory
-                    .as_ref()
-                    .map(|sub| PathBuf::from(sub.as_str()).into_boxed_path()),
+                subdirectory: if subdirectory.is_empty() {
+                    None
+                } else {
+                    Some(subdirectory.as_path().to_path_buf().into_boxed_path())
+                },
                 location: location_url.into(),
                 url: verbatim_url,
                 ext: DistExtension::from_path(url.path())?,
@@ -220,7 +224,7 @@ pub fn as_uv_req(
             .iter()
             .map(|e| uv_normalize::ExtraName::from_str(e.as_ref()).expect("conversion failed"))
             .collect(),
-        marker: Default::default(),
+        marker: to_uv_marker_tree(req.env_markers()).expect("marker conversion failed"),
         groups: Default::default(),
         source,
         origin: None,
@@ -309,10 +313,47 @@ pub fn pep508_requirement_to_uv_requirement(
 
 #[cfg(test)]
 mod tests {
+    use pep508_rs::MarkerTree;
     use uv_redacted::DisplaySafeUrl;
 
     use super::*;
 
+    #[test]
+    fn test_markers() {
+        let pypi_req = PixiPypiSpec::with_extras_and_markers(
+            PixiPypiSource::Registry {
+                version: VersionOrStar::Star,
+                index: None,
+            },
+            vec![],
+            MarkerTree::from_str("sys_platform == 'linux'").unwrap(),
+        );
+        let uv_req = as_uv_req(&pypi_req, "test", Path::new("")).unwrap();
+
+        let expected_uv_source = RequirementSource::Registry {
+            specifier: VersionSpecifiers::empty(),
+            index: None,
+            conflict: None,
+        };
+
+        assert_eq!(
+            uv_req.source, expected_uv_source,
+            "Expected {} but got {}",
+            expected_uv_source, uv_req.source
+        );
+
+        let expected_uv_markers =
+            uv_pep508::MarkerTree::from_str("sys_platform == 'linux'").unwrap();
+
+        assert_eq!(
+            uv_req.marker,
+            expected_uv_markers,
+            "Expected {:?} but got {:?}",
+            expected_uv_markers.try_to_string(),
+            uv_req.marker.try_to_string(),
+        );
+    }
+
     #[test]
     fn test_git_url() {
         let pypi_req = PixiPypiSpec::new(PixiPypiSource::Git {
@@ -321,7 +362,7 @@ mod tests {
                 rev: Some(GitReference::Rev(
                     "d099af3b1028b00c232d8eda28a997984ae5848b".to_string(),
                 )),
-                subdirectory: None,
+                subdirectory: Default::default(),
             },
         });
         let uv_req = as_uv_req(&pypi_req, "test", Path::new("")).unwrap();
@@ -331,7 +372,7 @@ mod tests {
                 DisplaySafeUrl::parse("ssh://git@github.com/user/test.git").unwrap(),
                 uv_git_types::GitReference::BranchOrTagOrCommit("d099af3b1028b00c232d8eda28a997984ae5848b".to_string()),
                 Some(uv_git_types::GitOid::from_str("d099af3b1028b00c232d8eda28a997984ae5848b").unwrap())).unwrap(),
-            subdirectory: None,
+            subdirectory: Default::default(),
             url: VerbatimUrl::from_url(DisplaySafeUrl::parse("git+ssh://git@github.com/user/test.git@d099af3b1028b00c232d8eda28a997984ae5848b").unwrap()),
         };
 
@@ -348,7 +389,7 @@ mod tests {
                 rev: Some(GitReference::Rev(
                     "d099af3b1028b00c232d8eda28a997984ae5848b".to_string(),
                 )),
-                subdirectory: None,
+                subdirectory: Default::default(),
             },
         });
         let uv_req = as_uv_req(&pypi_req, "test", Path::new("")).unwrap();
@@ -364,7 +405,7 @@ mod tests {
                 ),
             )
             .unwrap(),
-            subdirectory: None,
+            subdirectory: Default::default(),
             url: VerbatimUrl::from_url(
                 DisplaySafeUrl::parse(
                     "git+https://github.com/user/test.git@d099af3b1028b00c232d8eda28a997984ae5848b",
@@ -381,7 +422,7 @@ mod tests {
             Url::parse("https://example.com/package.tar.gz#sha256=abc123def456").unwrap();
         let pypi_req = PixiPypiSpec::new(PixiPypiSource::Url {
             url: url_with_hash.clone(),
-            subdirectory: None,
+            subdirectory: Default::default(),
         });
 
         let uv_req = as_uv_req(&pypi_req, "test-package", Path::new("")).unwrap();
