@@ -267,7 +267,6 @@ class SourceSpecTable(StrictBaseModel):
 
 MatchSpec = NonEmptyStr | MatchspecTable
 CondaPackageName = NonEmptyStr
-EnvironmentMarkers = NonEmptyStr
 
 
 class _PyPIRequirement(StrictBaseModel):
@@ -275,10 +274,6 @@ class _PyPIRequirement(StrictBaseModel):
         None,
         description="The [PEP 508 extras](https://peps.python.org/pep-0508/#extras) of the package",
     )
-    env_markers: EnvironmentMarkers | None = Field(
-        None,
-        description="The [PEP 508 markers](https://peps.python.org/pep-0508/#environment-markers) of the package",
-    )
 
 
 class _PyPiGitRequirement(_PyPIRequirement):
