@@ -1,5 +1,6 @@
 import os
 import platform
+import re
 import subprocess
 import sys
 from collections.abc import Sequence
@@ -9,7 +10,10 @@ from typing import override
 
 from rattler import Platform
 
-PIXI_VERSION = "0.63.1"
+# Regex pattern to match ANSI escape sequences
+ANSI_ESCAPE_PATTERN = re.compile(r"\x1b\[[0-9;]*m")
+
+PIXI_VERSION = "0.63.2"
 
 
 ALL_PLATFORMS = '["linux-64", "osx-64", "osx-arm64", "win-64", "linux-ppc64le", "linux-aarch64"]'
@@ -60,8 +64,11 @@ def verify_cli_command(
     env: dict[str, str] | None = None,
     cwd: str | Path | None = None,
     reset_env: bool = False,
+    strip_ansi: bool = False,
 ) -> Output:
     base_env = {} if reset_env else dict(os.environ)
+    # Remove all PIXI_ prefixed env vars to avoid interference from the outer environment
+    base_env = {k: v for k, v in base_env.items() if not k.startswith("PIXI_")}
     complete_env = base_env if env is None else base_env | env
     # Set `PIXI_NO_WRAP` to avoid to have miette wrapping lines
     complete_env |= {"PIXI_NO_WRAP": "1"}
@@ -75,6 +82,11 @@ def verify_cli_command(
     # Decode stdout and stderr explicitly using UTF-8
     stdout = process.stdout.decode("utf-8", errors="replace")
     stderr = process.stderr.decode("utf-8", errors="replace")
+
+    # Optionally strip ANSI escape sequences for matching
+    stdout_for_matching = ANSI_ESCAPE_PATTERN.sub("", stdout) if strip_ansi else stdout
+    stderr_for_matching = ANSI_ESCAPE_PATTERN.sub("", stderr) if strip_ansi else stderr
+
     returncode = process.returncode
     output = Output(command, stdout, stderr, returncode)
     print(f"command: {command}, stdout: {stdout}, stderr: {stderr}, code: {returncode}")
@@ -86,13 +98,15 @@ def verify_cli_command(
         if isinstance(stdout_contains, str):
             stdout_contains = [stdout_contains]
         for substring in stdout_contains:
-            assert substring in stdout, f"'{substring}'\n not found in stdout:\n {stdout}"
+            assert substring in stdout_for_matching, (
+                f"'{substring}'\n not found in stdout:\n {stdout}"
+            )
 
     if stdout_excludes:
         if isinstance(stdout_excludes, str):
             stdout_excludes = [stdout_excludes]
         for substring in stdout_excludes:
-            assert substring not in stdout, (
+            assert substring not in stdout_for_matching, (
                 f"'{substring}'\n unexpectedly found in stdout:\n {stdout}"
             )
 
@@ -100,13 +114,15 @@ def verify_cli_command(
         if isinstance(stderr_contains, str):
             stderr_contains = [stderr_contains]
         for substring in stderr_contains:
-            assert substring in stderr, f"'{substring}'\n not found in stderr:\n {stderr}"
+            assert substring in stderr_for_matching, (
+                f"'{substring}'\n not found in stderr:\n {stderr}"
+            )
 
     if stderr_excludes:
         if isinstance(stderr_excludes, str):
             stderr_excludes = [stderr_excludes]
         for substring in stderr_excludes:
-            assert substring not in stderr, (
+            assert substring not in stderr_for_matching, (
                 f"'{substring}'\n unexpectedly found in stderr:\n {stderr}"
             )
 
