@@ -12,6 +12,7 @@ from .common import (
 )
 
 
+@pytest.mark.slow
 def test_upgrade_package_does_not_exist(
     pixi: Path, tmp_pixi_workspace: Path, multiple_versions_channel_1: str
 ) -> None:
@@ -78,6 +79,7 @@ def test_upgrade_conda_package(
     assert "build-number" not in package
 
 
+@pytest.mark.slow
 def test_upgrade_exclude(
     pixi: Path, tmp_pixi_workspace: Path, multiple_versions_channel_1: str
 ) -> None:
@@ -132,6 +134,7 @@ def test_upgrade_json_output(
     assert data["environment"]["default"]
 
 
+@pytest.mark.slow
 def test_upgrade_dryrun(
     pixi: Path, tmp_pixi_workspace: Path, multiple_versions_channel_1: str
 ) -> None:
@@ -257,7 +260,7 @@ cli = ["rich==12"]
 [dependency-groups]
 test = ["pytest==6"]
 
-[tool.pixi.project]
+[tool.pixi.workspace]
 channels = ["https://prefix.dev/conda-forge"]
 platforms = ["{CURRENT_PLATFORM}"]
 
@@ -297,6 +300,7 @@ test = ["test"]
     assert "numpy" not in pypi_dependencies
 
 
+@pytest.mark.slow
 def test_upgrade_keep_info(
     pixi: Path, tmp_pixi_workspace: Path, multiple_versions_channel_1: str
 ) -> None:
@@ -320,26 +324,26 @@ def test_upgrade_keep_info(
     assert "ab*" in parsed_manifest["dependencies"]["package3"]["build"]
     assert multiple_versions_channel_1 in parsed_manifest["dependencies"]["package3"]["channel"]
 
-    # Upgrade all, it should now be at 0.2.0, with the build intact
+    # Upgrade all, it should now be at 0.3.0, with the build intact
     verify_cli_command(
         [pixi, "upgrade", "--manifest-path", manifest_path],
-        stderr_contains=["package3", "0.1.0", "0.2.0"],
+        stderr_contains=["package3", "0.1.0", "0.3.0"],
     )
     parsed_manifest = tomllib.loads(manifest_path.read_text())
     # Update version
-    assert parsed_manifest["dependencies"]["package3"]["version"] == ">=0.2.0,<0.3"
+    assert parsed_manifest["dependencies"]["package3"]["version"] == ">=0.3.0,<0.4"
     # Keep build
     assert "ab*" in parsed_manifest["dependencies"]["package3"]["build"]
     # Keep channel
     assert multiple_versions_channel_1 in parsed_manifest["dependencies"]["package3"]["channel"]
 
-    # Upgrade package3, it should now be at 0.2.0, with the build intact because it has a wildcard
+    # Upgrade package3, it should stay at 0.3.0, with the build intact because it has a wildcard
     verify_cli_command(
         [pixi, "upgrade", "--manifest-path", manifest_path, "package3"],
     )
     parsed_manifest = tomllib.loads(manifest_path.read_text())
     # Update version
-    assert parsed_manifest["dependencies"]["package3"]["version"] == ">=0.2.0,<0.3"
+    assert parsed_manifest["dependencies"]["package3"]["version"] == ">=0.3.0,<0.4"
     # Keep build
     assert "ab*" in parsed_manifest["dependencies"]["package3"]["build"]
     # Keep channel
@@ -369,19 +373,20 @@ def test_upgrade_remove_info(
     assert "abc" in parsed_manifest["dependencies"]["package3"]["build"]
     assert multiple_versions_channel_1 in parsed_manifest["dependencies"]["package3"]["channel"]
 
-    # Upgrade package3, it should now be at 0.2.0, without the build but with the channel
+    # Upgrade package3, it should now be at 0.3.0, without the build but with the channel
     verify_cli_command(
         [pixi, "upgrade", "--manifest-path", manifest_path, "package3"],
     )
     parsed_manifest = tomllib.loads(manifest_path.read_text())
     # Update version
-    assert parsed_manifest["dependencies"]["package3"]["version"] == ">=0.2.0,<0.3"
+    assert parsed_manifest["dependencies"]["package3"]["version"] == ">=0.3.0,<0.4"
     # Keep channel
     assert multiple_versions_channel_1 in parsed_manifest["dependencies"]["package3"]["channel"]
     # Remove build
     assert "build" not in parsed_manifest["dependencies"]["package3"]
 
 
+@pytest.mark.slow
 def test_upgrade_features(
     pixi: Path, tmp_pixi_workspace: Path, multiple_versions_channel_1: str
 ) -> None:
@@ -482,13 +487,13 @@ def test_upgrade_features(
     verify_cli_command(
         [pixi, "upgrade", "--manifest-path", manifest_path, "--feature=foo"],
         stderr_excludes=["package2"],
-        stderr_contains=["package3", "0.1.0", "0.2.0"],
+        stderr_contains=["package3", "0.1.0", "0.3.0"],
     )
     parsed_manifest = tomllib.loads(manifest_path.read_text())
     package3 = parsed_manifest["feature"]["foo"]["dependencies"]["package3"]
     package2 = parsed_manifest["feature"]["bar"]["dependencies"]["package2"]
     assert package2["version"] == "==0.1.0"
-    assert package3["version"] == ">=0.2.0,<0.3"
+    assert package3["version"] == ">=0.3.0,<0.4"
 
     # Upgrading with no specified feature should upgrade all features (hence "package2" in feature "bar")
     verify_cli_command(
